@@ -1,11 +1,10 @@
 /*
-   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "sieveeditorconfiguredialog.h"
-#include "serversievelistwidget.h"
 #include "sieveeditorconfigureserverwidget.h"
 #include "sieveeditorglobalconfig.h"
 #include <PimCommon/ConfigureImmutableWidgetUtils>
@@ -20,10 +19,17 @@
 #include <KSharedConfig>
 
 #include <KConfigGroup>
+#include <KWindowConfig>
 #include <QCheckBox>
 #include <QDialogButtonBox>
 #include <QPushButton>
 #include <QVBoxLayout>
+#include <QWindow>
+
+namespace
+{
+static const char mySieveEditorConfigureDialog[] = "SieveEditorConfigureDialog";
+}
 
 SieveEditorConfigureDialog::SieveEditorConfigureDialog(QWidget *parent)
     : KPageDialog(parent)
@@ -106,16 +112,16 @@ void SieveEditorConfigureDialog::saveServerSieveConfig()
 
 void SieveEditorConfigureDialog::readConfig()
 {
-    KConfigGroup group(KSharedConfig::openStateConfig(), "SieveEditorConfigureDialog");
-    const QSize size = group.readEntry("Size", QSize(600, 400));
-    if (size.isValid()) {
-        resize(size);
-    }
+    create(); // ensure a window is created
+    windowHandle()->resize(QSize(600, 400));
+    KConfigGroup group(KSharedConfig::openStateConfig(), mySieveEditorConfigureDialog);
+    KWindowConfig::restoreWindowSize(windowHandle(), group);
+    resize(windowHandle()->size()); // workaround for QTBUG-40584
 }
 
 void SieveEditorConfigureDialog::writeConfig()
 {
-    KConfigGroup group(KSharedConfig::openStateConfig(), "SieveEditorConfigureDialog");
-    group.writeEntry("Size", size());
+    KConfigGroup group(KSharedConfig::openStateConfig(), mySieveEditorConfigureDialog);
+    KWindowConfig::saveWindowSize(windowHandle(), group);
     group.sync();
 }
